/**
 * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
 * LICENSE. This work is protected by copyright and/or other applicable
 * law. Any use of the work other than as authorized under this license
 * or copyright law is prohibited.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 * © 2017 OX Software GmbH, Germany. info@open-xchange.com
 *
 * @author Greg Hill <greg.hill@open-xchange.com>
 */

/**
 * Handles change password prompt for first time user
 * 
 */


module.exports  = function (userdata) {
    this.waitForVisible('#newogpassword');
    this.insertCryptPassword('#newogpassword', userdata);
    this.waitForVisible('.oxguard_hint_warn');
    this.insertCryptPassword('#newogpassword2', userdata);
    this.click('.btn[data-action="okpass"]');
}